@@ -3,17 +3,17 @@ use strict;
 use warnings;
 
 ## no critic qw(ProhibitLongLines)
-# $Id: Hyphenate.pm 114 2009-08-02 19:12:48Z roland $
-# $Revision: 114 $
+# $Id: Hyphenate.pm 321 2010-10-30 18:06:08Z roland $
+# $Revision: 321 $
 # $HeadURL: svn+ssh://ipenburg.xs4all.nl/srv/svnroot/elaine/trunk/HTML-Hyphenate/lib/HTML/Hyphenate.pm $
-# $Date: 2009-08-02 21:12:48 +0200 (Sun, 02 Aug 2009) $
+# $Date: 2010-10-30 20:06:08 +0200 (Sat, 30 Oct 2010) $
 ## use critic
 
 use 5.006000;
 use utf8;
 use charnames qw(:full);
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 use Log::Log4perl qw(:easy get_logger);
 use Set::Scalar;
@@ -64,7 +64,7 @@ my $ANYTHING = qr/.*/xsm;
 my $text_attr = Set::Scalar->new(qw/abbr alt label standby summary title/);
 
 # Strip document root tags from a fragment added by HTML::TreeBuilder:
-my $ROOT = qr{^<html>(?:<head></head>)??<body>(.*)</body></html>\s*$}ixsm;
+my $ROOT = qr{ ^<html>(?:<head></head>)??<body>(.*)</body></html>\s*$ }ixsm;
 
 # Match inline style requesting not to wrap anyway:
 my $STYLE_NOWRAP = qr/\bwhite-space\s*:\s*nowrap\b/xsm;
@@ -333,7 +333,7 @@ HTML::Hyphenate - class for inserting soft hyphens into HTML.
 
 =head1 VERSION
 
-This is version 0.03.
+This is version 0.04.
 
 =head1 SYNOPSIS
 
@@ -378,8 +378,8 @@ Gets or sets the HTML to hyphenate.
 
 =item $hyphenator->style();
 
-Gets or sets the style to use for pattern usages in L<TeX::Hyphen>. Can be
-C<czech> or C<german>.
+Gets or sets the style to use for pattern usages in
+L<TeX::Hyphen|TeX::Hyphen>. Can be C<czech> or C<german>.
 
 =item $hyphenator->min_length();
 
@@ -398,7 +398,7 @@ last soft hyphen. Defaults to 2 characters.
 
 =item $hyphenator->output_xml(1);
 
-Have L<HTML::TreeBuilder> output HTML in HTML or XML modus. 
+Have L<HTML::TreeBuilder|HTML::TreeBuilder> output HTML in HTML or XML modus. 
 
 =item $hyphenator->default_lang('en-us');
 
@@ -424,18 +424,18 @@ inserted.
 
 =head1 DEPENDENCIES
 
-L<Class::Meta::Express>
-L<Class::Meta::Type>
-L<HTML::Entities>
-L<HTML::Hyphenate::TypeDef>
-L<HTML::TreeBuilder>
-L<Log::Log4perl>
-L<Readonly>
-L<Set::Scalar>
-L<TeX::Hyphen>
-L<TeX::Hyphen::Pattern>
-L<Test::More>
-L<Test::NoWarnings>
+L<Class::Meta::Express|Class::Meta::Express>
+L<Class::Meta::Type|Class::Meta::Type>
+L<HTML::Entities|HTML::Entities>
+L<HTML::Hyphenate::TypeDef|HTML::Hyphenate::TypeDef>
+L<HTML::TreeBuilder|HTML::TreeBuilder>
+L<Log::Log4perl|Log::Log4perl>
+L<Readonly|Readonly>
+L<Set::Scalar|Set::Scalar>
+L<TeX::Hyphen|TeX::Hyphen>
+L<TeX::Hyphen::Pattern|TeX::Hyphen::Pattern>
+L<Test::More|Test::More>
+L<Test::NoWarnings|Test::NoWarnings>
 
 =head1 INCOMPATIBILITIES
 
@@ -491,7 +491,8 @@ transformed to HTML encoded entity equivalent.
 
 =head1 CONFIGURATION AND ENVIRONMENT
 
-The output is generated by L<HTML::TreeBuilder> and can be either HTML or XML.
+The output is generated by L<HTML::TreeBuilder|HTML::TreeBuilder> and can be
+either HTML or XML.
 
 =head1 AUTHOR
 
@@ -499,7 +500,7 @@ Roland van Ipenburg  C<< <ipenburg@xs4all.nl> >>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (C) 2009 by Roland van Ipenburg
+Copyright (C) 2010 by Roland van Ipenburg
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.10.0 or,
